"""MathML operator dictionary and related functions"""
import sys

operatorDictionary = {}

def lookup(op, form = "infix"):
    """Find the entry for an operator in the dictionary"""
    res = operatorDictionary.get(op+form)
    if res is not None: return res 
    
    for f in ["infix", "postfix", "prefix"]:
        res = operatorDictionary.get(op+f)
        if res is not None: return res 
    
    return operatorDictionary[""+"infix"]  # default entry

    
def createEntry( content, 
                 form = "infix", 
                 fence = "false", 
                 separator = "false",
                 accent = "false",
                 largeop = "false",
                 lspace = "thickmathspace", 
                 rspace = "thickmathspace",
                 stretchy = "false", 
                 scaling = "uniform", 
                 minsize = "1", 
                 maxsize = "infinity", 
                 movablelimits = "false",
                 symmetric = "true" ) :
    if content+form in list(operatorDictionary.keys()):
        sys.stderr.write("WARNING: duplicate entry in operator dictionary, %s %s\n" %(form, str(content)))
    operatorDictionary[content+form] = { "form": form,
                                         "fence": fence,
                                         "separator": separator,
                                         "accent": accent,
                                         "largeop": largeop,
                                         "lspace": lspace, 
                                         "rspace": rspace,
                                         "stretchy": stretchy, 
                                         "scaling": scaling, 
                                         "minsize": minsize, 
                                         "maxsize": maxsize, 
                                         "movablelimits": movablelimits,
                                         "symmetric": symmetric } 
                
# Create default entry
createEntry (content="")

# Create real entries
createEntry (content="(", form="prefix", fence="true", stretchy="true", scaling="vertical", lspace="0em", rspace="0em")
createEntry (content=")", form="postfix", fence="true", stretchy="true", scaling="vertical", lspace="0em", rspace="0em")
createEntry (content="[", form="prefix", fence="true", stretchy="true", scaling="vertical", lspace="0em", rspace="0em")
createEntry (content="]", form="postfix", fence="true", stretchy="true", scaling="vertical", lspace="0em", rspace="0em")
createEntry (content="{", form="prefix", fence="true", stretchy="true", scaling="vertical", lspace="0em", rspace="0em")
createEntry (content="}", form="postfix", fence="true", stretchy="true", scaling="vertical", lspace="0em", rspace="0em")
createEntry (content="\u201D", form="postfix", fence="true", lspace="0em", rspace="0em") # CloseCurlyDoubleQuote
createEntry (content="\u2019", form="postfix", fence="true", lspace="0em", rspace="0em") # CloseCurlyQuote
createEntry (content="\u2329", form="prefix", fence="true", stretchy="true", scaling="vertical", lspace="0em", rspace="0em") # LeftAngleBracket
createEntry (content="\u2308", form="prefix", fence="true", stretchy="true", scaling="vertical", lspace="0em", rspace="0em") # LeftCeiling
createEntry (content="\u301A", form="prefix", fence="true", stretchy="true", scaling="vertical", lspace="0em", rspace="0em") # LeftDoubleBracket
createEntry (content="\u230A", form="prefix", fence="true", stretchy="true", scaling="vertical", lspace="0em", rspace="0em") # LeftFloor
createEntry (content="\u201C", form="prefix", fence="true", lspace="0em", rspace="0em") # OpenCurlyDoubleQuote
createEntry (content="\u2018", form="prefix", fence="true", lspace="0em", rspace="0em") # OpenCurlyQuote
createEntry (content="\u232A", form="postfix", fence="true", stretchy="true", scaling="vertical", lspace="0em", rspace="0em") # RightAngleBracket
createEntry (content="\u2309", form="postfix", fence="true", stretchy="true", scaling="vertical", lspace="0em", rspace="0em") # RightCeiling
createEntry (content="\u301B", form="postfix", fence="true", stretchy="true", scaling="vertical", lspace="0em", rspace="0em") # RightDoubleBracket
createEntry (content="\u230B", form="postfix", fence="true", stretchy="true", scaling="vertical", lspace="0em", rspace="0em") # RightFloor
createEntry (content="\u2063", form="infix", separator="true", lspace="0em", rspace="0em") # InvisibleComma
createEntry (content=",", form="infix", separator="true", lspace="0em", rspace="verythickmathspace")
createEntry (content="\u2500", form="infix", stretchy="true", scaling="horizontal", minsize="0", lspace="0em", rspace="0em") # HorizontalLine
# Commented out: collides with '|'. See http://lists.w3.org/Archives/Public/www-math/2004Mar/0028.html
# createEntry (content=u"|", form=u"infix", stretchy=u"true", scaling="vertical", minsize=u"0", lspace=u"0em", rspace=u"0em") # VerticalLine 
createEntry (content=";", form="infix", separator="true", lspace="0em", rspace="thickmathspace")
createEntry (content=";", form="postfix", separator="true", lspace="0em", rspace="0em")
createEntry (content=":=", form="infix", lspace="thickmathspace", rspace="thickmathspace")
createEntry (content="\u2254", form="infix", lspace="thickmathspace", rspace="thickmathspace") # Assign
createEntry (content="\u2235", form="infix", lspace="thickmathspace", rspace="thickmathspace") # Because
createEntry (content="\u2234", form="infix", lspace="thickmathspace", rspace="thickmathspace") # Therefore
createEntry (content="\u2758", form="infix", stretchy="true", scaling="vertical", lspace="thickmathspace", rspace="thickmathspace") # VerticalSeparator
createEntry (content="//", form="infix", lspace="thickmathspace", rspace="thickmathspace")
# Commented out: collides with Proportional
# createEntry (content=u"\u2237", form=u"infix", lspace=u"thickmathspace", rspace=u"thickmathspace") # Colon
createEntry (content="&", form="prefix", lspace="0em", rspace="thickmathspace")
createEntry (content="&", form="postfix", lspace="thickmathspace", rspace="0em")
createEntry (content="*=", form="infix", lspace="thickmathspace", rspace="thickmathspace")
createEntry (content="-=", form="infix", lspace="thickmathspace", rspace="thickmathspace")
createEntry (content="+=", form="infix", lspace="thickmathspace", rspace="thickmathspace")
createEntry (content="/=", form="infix", lspace="thickmathspace", rspace="thickmathspace")
createEntry (content="->", form="infix", lspace="thickmathspace", rspace="thickmathspace")
createEntry (content=":", form="infix", lspace="thickmathspace", rspace="thickmathspace")
createEntry (content="..", form="postfix", lspace="mediummathspace", rspace="0em")
createEntry (content="...", form="postfix", lspace="mediummathspace", rspace="0em")
# Commented out: collides with ReverseElement
# createEntry (content=u"\u220B", form=u"infix", lspace=u"thickmathspace", rspace=u"thickmathspace") # SuchThat
createEntry (content="\u2AE4", form="infix", lspace="thickmathspace", rspace="thickmathspace") # DoubleLeftTee
createEntry (content="\u22A8", form="infix", lspace="thickmathspace", rspace="thickmathspace") # DoubleRightTee
createEntry (content="\u22A4", form="infix", lspace="thickmathspace", rspace="thickmathspace") # DownTee
createEntry (content="\u22A3", form="infix", lspace="thickmathspace", rspace="thickmathspace") # LeftTee
createEntry (content="\u22A2", form="infix", lspace="thickmathspace", rspace="thickmathspace") # RightTee
# Commented out: collides with DoubleRightArrow
# createEntry (content=u"\u21D2", form=u"infix", stretchy=u"true", scaling="horizontal", lspace=u"thickmathspace", rspace=u"thickmathspace") # Implies
createEntry (content="\u2970", form="infix", lspace="thickmathspace", rspace="thickmathspace") # RoundImplies
createEntry (content="|", form="infix", stretchy="true", scaling="vertical", lspace="thickmathspace", rspace="thickmathspace")
createEntry (content="||", form="infix", lspace="mediummathspace", rspace="mediummathspace")
createEntry (content="\u2A54", form="infix", stretchy="true", scaling="uniform", lspace="mediummathspace", rspace="mediummathspace") # Or
createEntry (content="&&", form="infix", lspace="thickmathspace", rspace="thickmathspace")
createEntry (content="\u2A53", form="infix", stretchy="true", scaling="uniform", lspace="mediummathspace", rspace="mediummathspace") # And
createEntry (content="&", form="infix", lspace="thickmathspace", rspace="thickmathspace")
createEntry (content="!", form="prefix", lspace="0em", rspace="thickmathspace")
createEntry (content="\u2AEC", form="prefix", lspace="0em", rspace="thickmathspace") # Not
createEntry (content="\u2203", form="prefix", lspace="0em", rspace="thickmathspace") # Exists
createEntry (content="\u2200", form="prefix", lspace="0em", rspace="thickmathspace") # ForAll
createEntry (content="\u2204", form="prefix", lspace="0em", rspace="thickmathspace") # NotExists
createEntry (content="\u2208", form="infix", lspace="thickmathspace", rspace="thickmathspace") # Element
createEntry (content="\u2209", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotElement
createEntry (content="\u220C", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotReverseElement
createEntry (content="\u228F\u0338", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotSquareSubset
createEntry (content="\u22E2", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotSquareSubsetEqual
createEntry (content="\u2290\u0338", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotSquareSuperset
createEntry (content="\u22E3", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotSquareSupersetEqual
createEntry (content="\u2282\u20D2", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotSubset
createEntry (content="\u2288", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotSubsetEqual
createEntry (content="\u2283\u20D2", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotSuperset
createEntry (content="\u2289", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotSupersetEqual
createEntry (content="\u220B", form="infix", lspace="thickmathspace", rspace="thickmathspace") # ReverseElement
createEntry (content="\u228F", form="infix", lspace="thickmathspace", rspace="thickmathspace") # SquareSubset
createEntry (content="\u2291", form="infix", lspace="thickmathspace", rspace="thickmathspace") # SquareSubsetEqual
createEntry (content="\u2290", form="infix", lspace="thickmathspace", rspace="thickmathspace") # SquareSuperset
createEntry (content="\u2292", form="infix", lspace="thickmathspace", rspace="thickmathspace") # SquareSupersetEqual
createEntry (content="\u22D0", form="infix", lspace="thickmathspace", rspace="thickmathspace") # Subset
createEntry (content="\u2286", form="infix", lspace="thickmathspace", rspace="thickmathspace") # SubsetEqual
createEntry (content="\u2283", form="infix", lspace="thickmathspace", rspace="thickmathspace") # Superset
createEntry (content="\u2287", form="infix", lspace="thickmathspace", rspace="thickmathspace") # SupersetEqual
createEntry (content="\u21D0", form="infix", stretchy="true", scaling="horizontal", lspace="thickmathspace", rspace="thickmathspace") # DoubleLeftArrow
createEntry (content="\u21D4", form="infix", stretchy="true", scaling="horizontal", lspace="thickmathspace", rspace="thickmathspace") # DoubleLeftRightArrow
createEntry (content="\u21D2", form="infix", stretchy="true", scaling="horizontal", lspace="thickmathspace", rspace="thickmathspace") # DoubleRightArrow
createEntry (content="\u2950", form="infix", stretchy="true", scaling="horizontal", lspace="thickmathspace", rspace="thickmathspace") # DownLeftRightVector
createEntry (content="\u295E", form="infix", stretchy="true", scaling="horizontal", lspace="thickmathspace", rspace="thickmathspace") # DownLeftTeeVector
createEntry (content="\u21BD", form="infix", stretchy="true", scaling="horizontal", lspace="thickmathspace", rspace="thickmathspace") # DownLeftVector
createEntry (content="\u2956", form="infix", stretchy="true", scaling="horizontal", lspace="thickmathspace", rspace="thickmathspace") # DownLeftVectorBar
createEntry (content="\u295F", form="infix", stretchy="true", scaling="horizontal", lspace="thickmathspace", rspace="thickmathspace") # DownRightTeeVector
createEntry (content="\u21C1", form="infix", stretchy="true", scaling="horizontal", lspace="thickmathspace", rspace="thickmathspace") # DownRightVector
createEntry (content="\u2957", form="infix", stretchy="true", scaling="horizontal", lspace="thickmathspace", rspace="thickmathspace") # DownRightVectorBar
createEntry (content="\u2190", form="infix", stretchy="true", scaling="horizontal", lspace="thickmathspace", rspace="thickmathspace") # LeftArrow
createEntry (content="\u21E4", form="infix", stretchy="true", scaling="horizontal", lspace="thickmathspace", rspace="thickmathspace") # LeftArrowBar
createEntry (content="\u21C6", form="infix", stretchy="true", scaling="horizontal", lspace="thickmathspace", rspace="thickmathspace") # LeftArrowRightArrow
createEntry (content="\u2194", form="infix", stretchy="true", scaling="horizontal", lspace="thickmathspace", rspace="thickmathspace") # LeftRightArrow
createEntry (content="\u294E", form="infix", stretchy="true", scaling="horizontal", lspace="thickmathspace", rspace="thickmathspace") # LeftRightVector
createEntry (content="\u21A4", form="infix", stretchy="true", scaling="horizontal", lspace="thickmathspace", rspace="thickmathspace") # LeftTeeArrow
createEntry (content="\u295A", form="infix", stretchy="true", scaling="horizontal", lspace="thickmathspace", rspace="thickmathspace") # LeftTeeVector
createEntry (content="\u21BC", form="infix", stretchy="true", scaling="horizontal", lspace="thickmathspace", rspace="thickmathspace") # LeftVector
createEntry (content="\u2952", form="infix", stretchy="true", scaling="horizontal", lspace="thickmathspace", rspace="thickmathspace") # LeftVectorBar
createEntry (content="\u2199", form="infix", stretchy="true", scaling="horizontal", lspace="thickmathspace", rspace="thickmathspace") # LowerLeftArrow
createEntry (content="\u2198", form="infix", stretchy="true", scaling="horizontal", lspace="thickmathspace", rspace="thickmathspace") # LowerRightArrow
createEntry (content="\u2192", form="infix", stretchy="true", scaling="horizontal", lspace="thickmathspace", rspace="thickmathspace") # RightArrow
createEntry (content="\u21E5", form="infix", stretchy="true", scaling="horizontal", lspace="thickmathspace", rspace="thickmathspace") # RightArrowBar
createEntry (content="\u21C4", form="infix", stretchy="true", scaling="horizontal", lspace="thickmathspace", rspace="thickmathspace") # RightArrowLeftArrow
createEntry (content="\u21A6", form="infix", stretchy="true", scaling="horizontal", lspace="thickmathspace", rspace="thickmathspace") # RightTeeArrow
createEntry (content="\u295B", form="infix", stretchy="true", scaling="horizontal", lspace="thickmathspace", rspace="thickmathspace") # RightTeeVector
createEntry (content="\u21C0", form="infix", stretchy="true", scaling="horizontal", lspace="thickmathspace", rspace="thickmathspace") # RightVector
createEntry (content="\u2953", form="infix", stretchy="true", scaling="horizontal", lspace="thickmathspace", rspace="thickmathspace") # RightVectorBar
# Commented out: collides with LeftArrow
# createEntry (content=u"\u2190", form=u"infix", lspace=u"thickmathspace", rspace=u"thickmathspace") # ShortLeftArrow
# Commented out: collides with RightArrow
# createEntry (content=u"\u2192", form=u"infix", lspace=u"thickmathspace", rspace=u"thickmathspace") # ShortRightArrow
createEntry (content="\u2196", form="infix", stretchy="true", scaling="uniform", lspace="thickmathspace", rspace="thickmathspace") # UpperLeftArrow
createEntry (content="\u2197", form="infix", stretchy="true", scaling="uniform", lspace="thickmathspace", rspace="thickmathspace") # UpperRightArrow
createEntry (content="=", form="infix", lspace="thickmathspace", rspace="thickmathspace")
createEntry (content="<", form="infix", lspace="thickmathspace", rspace="thickmathspace")
createEntry (content=">", form="infix", lspace="thickmathspace", rspace="thickmathspace")
createEntry (content="!=", form="infix", lspace="thickmathspace", rspace="thickmathspace")
createEntry (content="==", form="infix", lspace="thickmathspace", rspace="thickmathspace")
createEntry (content="<=", form="infix", lspace="thickmathspace", rspace="thickmathspace")
createEntry (content=">=", form="infix", lspace="thickmathspace", rspace="thickmathspace")
createEntry (content="\u2261", form="infix", lspace="thickmathspace", rspace="thickmathspace") # Congruent
createEntry (content="\u224D", form="infix", lspace="thickmathspace", rspace="thickmathspace") # CupCap
createEntry (content="\u2250", form="infix", lspace="thickmathspace", rspace="thickmathspace") # DotEqual
createEntry (content="\u2225", form="infix", lspace="thickmathspace", rspace="thickmathspace") # DoubleVerticalBar
createEntry (content="\u2A75", form="infix", lspace="thickmathspace", rspace="thickmathspace") # Equal
createEntry (content="\u2242", form="infix", lspace="thickmathspace", rspace="thickmathspace") # EqualTilde
createEntry (content="\u21CC", form="infix", stretchy="true", scaling="horizontal", lspace="thickmathspace", rspace="thickmathspace") # Equilibrium
createEntry (content="\u2265", form="infix", lspace="thickmathspace", rspace="thickmathspace") # GreaterEqual
createEntry (content="\u22DB", form="infix", lspace="thickmathspace", rspace="thickmathspace") # GreaterEqualLess
createEntry (content="\u2267", form="infix", lspace="thickmathspace", rspace="thickmathspace") # GreaterFullEqual
createEntry (content="\u2AA2", form="infix", lspace="thickmathspace", rspace="thickmathspace") # GreaterGreater
createEntry (content="\u2277", form="infix", lspace="thickmathspace", rspace="thickmathspace") # GreaterLess
createEntry (content="\u2A7E", form="infix", lspace="thickmathspace", rspace="thickmathspace") # GreaterSlantEqual
createEntry (content="\u2273", form="infix", lspace="thickmathspace", rspace="thickmathspace") # GreaterTilde
createEntry (content="\u224E", form="infix", lspace="thickmathspace", rspace="thickmathspace") # HumpDownHump
createEntry (content="\u224F", form="infix", lspace="thickmathspace", rspace="thickmathspace") # HumpEqual
createEntry (content="\u22B2", form="infix", lspace="thickmathspace", rspace="thickmathspace") # LeftTriangle
createEntry (content="\u29CF", form="infix", lspace="thickmathspace", rspace="thickmathspace") # LeftTriangleBar
createEntry (content="\u22B4", form="infix", lspace="thickmathspace", rspace="thickmathspace") # LeftTriangleEqual
createEntry (content="\u2264", form="infix", lspace="thickmathspace", rspace="thickmathspace") # le
createEntry (content="\u22DA", form="infix", lspace="thickmathspace", rspace="thickmathspace") # LessEqualGreater
createEntry (content="\u2266", form="infix", lspace="thickmathspace", rspace="thickmathspace") # LessFullEqual
createEntry (content="\u2276", form="infix", lspace="thickmathspace", rspace="thickmathspace") # LessGreater
createEntry (content="\u2AA1", form="infix", lspace="thickmathspace", rspace="thickmathspace") # LessLess
createEntry (content="\u2A7D", form="infix", lspace="thickmathspace", rspace="thickmathspace") # LessSlantEqual
createEntry (content="\u2272", form="infix", lspace="thickmathspace", rspace="thickmathspace") # LessTilde
createEntry (content="\u226B", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NestedGreaterGreater
createEntry (content="\u226A", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NestedLessLess
createEntry (content="\u2262", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotCongruent
createEntry (content="\u226D", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotCupCap
createEntry (content="\u2226", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotDoubleVerticalBar
createEntry (content="\u2260", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotEqual
createEntry (content="\u2242\u0338", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotEqualTilde
createEntry (content="\u226F", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotGreater
createEntry (content="\u2271", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotGreaterEqual
createEntry (content="\u2266\u0338", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotGreaterFullEqual
createEntry (content="\u226B\u0338", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotGreaterGreater
createEntry (content="\u2279", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotGreaterLess
createEntry (content="\u2A7E\u0338", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotGreaterSlantEqual
createEntry (content="\u2275", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotGreaterTilde
createEntry (content="\u224E\u0338", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotHumpDownHump
createEntry (content="\u224F\u0338", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotHumpEqual
createEntry (content="\u22EA", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotLeftTriangle
createEntry (content="\u29CF\u0338", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotLeftTriangleBar
createEntry (content="\u22EC", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotLeftTriangleEqual
createEntry (content="\u226E", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotLess
createEntry (content="\u2270", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotLessEqual
createEntry (content="\u2278", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotLessGreater
createEntry (content="\u226A\u0338", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotLessLess
createEntry (content="\u2A7D\u0338", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotLessSlantEqual
createEntry (content="\u2274", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotLessTilde
createEntry (content="\u2AA2\u0338", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotNestedGreaterGreater
createEntry (content="\u2AA1\u0338", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotNestedLessLess
createEntry (content="\u2280", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotPrecedes
createEntry (content="\u2AAF\u0338", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotPrecedesEqual
createEntry (content="\u22E0", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotPrecedesSlantEqual
createEntry (content="\u22EB", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotRightTriangle
createEntry (content="\u29D0\u0338", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotRightTriangleBar
createEntry (content="\u22ED", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotRightTriangleEqual
createEntry (content="\u2281", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotSucceeds
createEntry (content="\u2AB0\u0338", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotSucceedsEqual
createEntry (content="\u22E1", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotSucceedsSlantEqual
createEntry (content="\u227F\u0338", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotSucceedsTilde
createEntry (content="\u2241", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotTilde
createEntry (content="\u2244", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotTildeEqual
createEntry (content="\u2247", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotTildeFullEqual
createEntry (content="\u2249", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotTildeTilde
createEntry (content="\u2224", form="infix", lspace="thickmathspace", rspace="thickmathspace") # NotVerticalBar
createEntry (content="\u227A", form="infix", lspace="thickmathspace", rspace="thickmathspace") # Precedes
createEntry (content="\u2AAF", form="infix", lspace="thickmathspace", rspace="thickmathspace") # PrecedesEqual
createEntry (content="\u227C", form="infix", lspace="thickmathspace", rspace="thickmathspace") # PrecedesSlantEqual
createEntry (content="\u227E", form="infix", lspace="thickmathspace", rspace="thickmathspace") # PrecedesTilde
createEntry (content="\u2237", form="infix", lspace="thickmathspace", rspace="thickmathspace") # Proportion
createEntry (content="\u221D", form="infix", lspace="thickmathspace", rspace="thickmathspace") # Proportional
createEntry (content="\u21CB", form="infix", stretchy="true", scaling="horizontal", lspace="thickmathspace", rspace="thickmathspace") # ReverseEquilibrium
createEntry (content="\u22B3", form="infix", lspace="thickmathspace", rspace="thickmathspace") # RightTriangle
createEntry (content="\u29D0", form="infix", lspace="thickmathspace", rspace="thickmathspace") # RightTriangleBar
createEntry (content="\u22B5", form="infix", lspace="thickmathspace", rspace="thickmathspace") # RightTriangleEqual
createEntry (content="\u227B", form="infix", lspace="thickmathspace", rspace="thickmathspace") # Succeeds
createEntry (content="\u2AB0", form="infix", lspace="thickmathspace", rspace="thickmathspace") # SucceedsEqual
createEntry (content="\u227D", form="infix", lspace="thickmathspace", rspace="thickmathspace") # SucceedsSlantEqual
createEntry (content="\u227F", form="infix", lspace="thickmathspace", rspace="thickmathspace") # SucceedsTilde
createEntry (content="\u223C", form="infix", lspace="thickmathspace", rspace="thickmathspace") # Tilde
createEntry (content="\u2243", form="infix", lspace="thickmathspace", rspace="thickmathspace") # TildeEqual
createEntry (content="\u2245", form="infix", lspace="thickmathspace", rspace="thickmathspace") # TildeFullEqual
createEntry (content="\u2248", form="infix", lspace="thickmathspace", rspace="thickmathspace") # TildeTilde
createEntry (content="\u22A5", form="infix", lspace="thickmathspace", rspace="thickmathspace") # UpTee
createEntry (content="\u2223", form="infix", lspace="thickmathspace", rspace="thickmathspace") # VerticalBar
createEntry (content="\u2294", form="infix", stretchy="true", scaling="uniform", lspace="mediummathspace", rspace="mediummathspace") # SquareUnion
createEntry (content="\u22C3", form="infix", stretchy="true", scaling="uniform", lspace="mediummathspace", rspace="mediummathspace") # Union
createEntry (content="\u228E", form="infix", stretchy="true", scaling="uniform", lspace="mediummathspace", rspace="mediummathspace") # UnionPlus
createEntry (content="-", form="infix", lspace="mediummathspace", rspace="mediummathspace")
# Added an entry for minus sign, separate from hyphen
createEntry (content="\u2212", form="infix", lspace="mediummathspace", rspace="mediummathspace")
createEntry (content="+", form="infix", lspace="mediummathspace", rspace="mediummathspace")
createEntry (content="\u22C2", form="infix", stretchy="true", scaling="uniform", lspace="mediummathspace", rspace="mediummathspace") # Intersection
createEntry (content="\u2213", form="infix", lspace="mediummathspace", rspace="mediummathspace") # MinusPlus
createEntry (content="\u00B1", form="infix", lspace="mediummathspace", rspace="mediummathspace") # PlusMinus
createEntry (content="\u2293", form="infix", stretchy="true", scaling="uniform", lspace="mediummathspace", rspace="mediummathspace") # SquareIntersection
createEntry (content="\u22C1", form="prefix", largeop="true", movablelimits="true", stretchy="true", scaling="uniform", lspace="0em", rspace="thinmathspace") # Vee
createEntry (content="\u2296", form="prefix", largeop="true", movablelimits="true", lspace="0em", rspace="thinmathspace") # CircleMinus
createEntry (content="\u2295", form="prefix", largeop="true", movablelimits="true", lspace="0em", rspace="thinmathspace") # CirclePlus
createEntry (content="\u2211", form="prefix", largeop="true", movablelimits="true", stretchy="true", scaling="uniform", lspace="0em", rspace="thinmathspace") # Sum
createEntry (content="\u22C3", form="prefix", largeop="true", movablelimits="true", stretchy="true", scaling="uniform", lspace="0em", rspace="thinmathspace") # Union
createEntry (content="\u228E", form="prefix", largeop="true", movablelimits="true", stretchy="true", scaling="uniform", lspace="0em", rspace="thinmathspace") # UnionPlus
createEntry (content="lim", form="prefix", movablelimits="true", lspace="0em", rspace="thinmathspace")
createEntry (content="max", form="prefix", movablelimits="true", lspace="0em", rspace="thinmathspace")
createEntry (content="min", form="prefix", movablelimits="true", lspace="0em", rspace="thinmathspace")
createEntry (content="\u2296", form="infix", lspace="thinmathspace", rspace="thinmathspace") # CircleMinus
createEntry (content="\u2295", form="infix", lspace="thinmathspace", rspace="thinmathspace") # CirclePlus
createEntry (content="\u2232", form="prefix", largeop="true", stretchy="true", scaling="uniform", lspace="0em", rspace="0em") # ClockwiseContourIntegral
createEntry (content="\u222E", form="prefix", largeop="true", stretchy="true", scaling="uniform", lspace="0em", rspace="0em") # ContourIntegral
createEntry (content="\u2233", form="prefix", largeop="true", stretchy="true", scaling="uniform", lspace="0em", rspace="0em") # CounterClockwiseContourIntegral
createEntry (content="\u222F", form="prefix", largeop="true", stretchy="true", scaling="uniform", lspace="0em", rspace="0em") # DoubleContourIntegral
createEntry (content="\u222B", form="prefix", largeop="true", stretchy="true", scaling="uniform", lspace="0em", rspace="0em") # Integral
createEntry (content="\u22D3", form="infix", lspace="thinmathspace", rspace="thinmathspace") # Cup
createEntry (content="\u22D2", form="infix", lspace="thinmathspace", rspace="thinmathspace") # Cap
createEntry (content="\u2240", form="infix", lspace="thinmathspace", rspace="thinmathspace") # VerticalTilde
createEntry (content="\u22C0", form="prefix", largeop="true", movablelimits="true", stretchy="true", scaling="uniform", lspace="0em", rspace="thinmathspace") # Wedge
createEntry (content="\u2297", form="prefix", largeop="true", movablelimits="true", lspace="0em", rspace="thinmathspace") # CircleTimes
createEntry (content="\u2210", form="prefix", largeop="true", movablelimits="true", stretchy="true", scaling="uniform", lspace="0em", rspace="thinmathspace") # Coproduct
createEntry (content="\u220F", form="prefix", largeop="true", movablelimits="true", stretchy="true", scaling="uniform", lspace="0em", rspace="thinmathspace") # Product
createEntry (content="\u22C2", form="prefix", largeop="true", movablelimits="true", stretchy="true", scaling="uniform", lspace="0em", rspace="thinmathspace") # Intersection
createEntry (content="\u2210", form="infix", lspace="thinmathspace", rspace="thinmathspace") # Coproduct
createEntry (content="\u22C6", form="infix", lspace="thinmathspace", rspace="thinmathspace") # Star
createEntry (content="\u2299", form="prefix", largeop="true", movablelimits="true", lspace="0em", rspace="thinmathspace") # CircleDot
createEntry (content="*", form="infix", lspace="thinmathspace", rspace="thinmathspace")
createEntry (content="\u2062", form="infix", lspace="0em", rspace="0em") # InvisibleTimes
createEntry (content="\u00B7", form="infix", lspace="thinmathspace", rspace="thinmathspace") # CenterDot
createEntry (content="\u2297", form="infix", lspace="thinmathspace", rspace="thinmathspace") # CircleTimes
createEntry (content="\u22C1", form="infix", lspace="thinmathspace", rspace="thinmathspace") # Vee
createEntry (content="\u22C0", form="infix", lspace="thinmathspace", rspace="thinmathspace") # Wedge
createEntry (content="\u22C4", form="infix", lspace="thinmathspace", rspace="thinmathspace") # Diamond
createEntry (content="\u2216", form="infix", stretchy="true", scaling="uniform", lspace="thinmathspace", rspace="thinmathspace") # Backslash
createEntry (content="/", form="infix", stretchy="true", scaling="uniform", lspace="thinmathspace", rspace="thinmathspace")
createEntry (content="-", form="prefix", lspace="0em", rspace="veryverythinmathspace")
# Added an entry for minus sign, separate from hyphen
createEntry (content="\u2212", form="prefix", lspace="0em", rspace="veryverythinmathspace")
createEntry (content="+", form="prefix", lspace="0em", rspace="veryverythinmathspace")
createEntry (content="\u2213", form="prefix", lspace="0em", rspace="veryverythinmathspace") # MinusPlus
createEntry (content="\u00B1", form="prefix", lspace="0em", rspace="veryverythinmathspace") # PlusMinus
createEntry (content=".", form="infix", lspace="0em", rspace="0em")
createEntry (content="\u2A2F", form="infix", lspace="verythinmathspace", rspace="verythinmathspace") # Cross
createEntry (content="**", form="infix", lspace="verythinmathspace", rspace="verythinmathspace")
createEntry (content="\u2299", form="infix", lspace="verythinmathspace", rspace="verythinmathspace") # CircleDot
createEntry (content="\u2218", form="infix", lspace="verythinmathspace", rspace="verythinmathspace") # SmallCircle
createEntry (content="\u25A1", form="prefix", lspace="0em", rspace="verythinmathspace") # Square
createEntry (content="\u2207", form="prefix", lspace="0em", rspace="verythinmathspace") # Del
createEntry (content="\u2202", form="prefix", lspace="0em", rspace="verythinmathspace") # PartialD
createEntry (content="\u2145", form="prefix", lspace="0em", rspace="verythinmathspace") # CapitalDifferentialD
createEntry (content="\u2146", form="prefix", lspace="0em", rspace="verythinmathspace") # DifferentialD
createEntry (content="\u221A", form="prefix", stretchy="true", scaling="uniform", lspace="0em", rspace="verythinmathspace") # Sqrt
createEntry (content="\u21D3", form="infix", stretchy="true", scaling="vertical", lspace="verythinmathspace", rspace="verythinmathspace") # DoubleDownArrow
createEntry (content="\u27F8", form="infix", stretchy="true", scaling="horizontal", lspace="verythinmathspace", rspace="verythinmathspace") # DoubleLongLeftArrow
createEntry (content="\u27FA", form="infix", stretchy="true", scaling="horizontal", lspace="verythinmathspace", rspace="verythinmathspace") # DoubleLongLeftRightArrow
createEntry (content="\u27F9", form="infix", stretchy="true", scaling="horizontal", lspace="verythinmathspace", rspace="verythinmathspace") # DoubleLongRightArrow
createEntry (content="\u21D1", form="infix", stretchy="true", scaling="vertical", lspace="verythinmathspace", rspace="verythinmathspace") # DoubleUpArrow
createEntry (content="\u21D5", form="infix", stretchy="true", scaling="vertical", lspace="verythinmathspace", rspace="verythinmathspace") # DoubleUpDownArrow
createEntry (content="\u2193", form="infix", stretchy="true", scaling="vertical", lspace="verythinmathspace", rspace="verythinmathspace") # DownArrow
createEntry (content="\u2913", form="infix", stretchy="true", scaling="vertical", lspace="verythinmathspace", rspace="verythinmathspace") # DownArrowBar
createEntry (content="\u21F5", form="infix", stretchy="true", scaling="vertical", lspace="verythinmathspace", rspace="verythinmathspace") # DownArrowUpArrow
createEntry (content="\u21A7", form="infix", stretchy="true", scaling="vertical", lspace="verythinmathspace", rspace="verythinmathspace") # DownTeeArrow
createEntry (content="\u2961", form="infix", stretchy="true", scaling="uniform", lspace="verythinmathspace", rspace="verythinmathspace") # LeftDownTeeVector
createEntry (content="\u21C3", form="infix", stretchy="true", scaling="uniform", lspace="verythinmathspace", rspace="verythinmathspace") # LeftDownVector
createEntry (content="\u2959", form="infix", stretchy="true", scaling="uniform", lspace="verythinmathspace", rspace="verythinmathspace") # LeftDownVectorBar
createEntry (content="\u2951", form="infix", stretchy="true", scaling="uniform", lspace="verythinmathspace", rspace="verythinmathspace") # LeftUpDownVector
createEntry (content="\u2960", form="infix", stretchy="true", scaling="uniform", lspace="verythinmathspace", rspace="verythinmathspace") # LeftUpTeeVector
createEntry (content="\u21BF", form="infix", stretchy="true", scaling="uniform", lspace="verythinmathspace", rspace="verythinmathspace") # LeftUpVector
createEntry (content="\u2958", form="infix", stretchy="true", scaling="uniform", lspace="verythinmathspace", rspace="verythinmathspace") # LeftUpVectorBar
createEntry (content="\u27F5", form="infix", stretchy="true", scaling="horizontal", lspace="verythinmathspace", rspace="verythinmathspace") # LongLeftArrow
createEntry (content="\u27F7", form="infix", stretchy="true", scaling="horizontal", lspace="verythinmathspace", rspace="verythinmathspace") # LongLeftRightArrow
createEntry (content="\u27F6", form="infix", stretchy="true", scaling="horizontal", lspace="verythinmathspace", rspace="verythinmathspace") # LongRightArrow
createEntry (content="\u296F", form="infix", stretchy="true", scaling="horizontal", lspace="verythinmathspace", rspace="verythinmathspace") # ReverseUpEquilibrium
createEntry (content="\u295D", form="infix", stretchy="true", scaling="horizontal", lspace="verythinmathspace", rspace="verythinmathspace") # RightDownTeeVector
createEntry (content="\u21C2", form="infix", stretchy="true", scaling="horizontal", lspace="verythinmathspace", rspace="verythinmathspace") # RightDownVector
createEntry (content="\u2955", form="infix", stretchy="true", scaling="horizontal", lspace="verythinmathspace", rspace="verythinmathspace") # RightDownVectorBar
createEntry (content="\u294F", form="infix", stretchy="true", scaling="horizontal", lspace="verythinmathspace", rspace="verythinmathspace") # RightUpDownVector
createEntry (content="\u295C", form="infix", stretchy="true", scaling="horizontal", lspace="verythinmathspace", rspace="verythinmathspace") # RightUpTeeVector
createEntry (content="\u21BE", form="infix", stretchy="true", scaling="horizontal", lspace="verythinmathspace", rspace="verythinmathspace") # RightUpVector
createEntry (content="\u2954", form="infix", stretchy="true", scaling="horizontal", lspace="verythinmathspace", rspace="verythinmathspace") # RightUpVectorBar
# Commented out: collides with DownArrow
# createEntry (content=u"\u2193", form=u"infix", lspace=u"verythinmathspace", rspace=u"verythinmathspace") # ShortDownArrow
# Commented out: collides with UpArrow
# createEntry (content=u"\u2191", form=u"infix", lspace=u"verythinmathspace", rspace=u"verythinmathspace") # ShortUpArrow
createEntry (content="\u2191", form="infix", stretchy="true", scaling="vertical", lspace="verythinmathspace", rspace="verythinmathspace") # UpArrow
createEntry (content="\u2912", form="infix", stretchy="true", scaling="vertical", lspace="verythinmathspace", rspace="verythinmathspace") # UpArrowBar
createEntry (content="\u21C5", form="infix", stretchy="true", scaling="vertical", lspace="verythinmathspace", rspace="verythinmathspace") # UpArrowDownArrow
createEntry (content="\u2195", form="infix", stretchy="true", scaling="vertical", lspace="verythinmathspace", rspace="verythinmathspace") # UpDownArrow
createEntry (content="\u296E", form="infix", stretchy="true", scaling="vertical", lspace="verythinmathspace", rspace="verythinmathspace") # UpEquilibrium
createEntry (content="\u21A5", form="infix", stretchy="true", scaling="vertical", lspace="verythinmathspace", rspace="verythinmathspace") # UpTeeArrow
createEntry (content="^", form="infix", lspace="verythinmathspace", rspace="verythinmathspace")
createEntry (content="<>", form="infix", lspace="verythinmathspace", rspace="verythinmathspace")
createEntry (content="'", form="postfix", lspace="verythinmathspace", rspace="0em")
# Added an entry for prime, separate from apostrophe
createEntry (content="\u2032", form="postfix", lspace="verythinmathspace", rspace="0em")
createEntry (content="!", form="postfix", lspace="verythinmathspace", rspace="0em")
createEntry (content="!!", form="postfix", lspace="verythinmathspace", rspace="0em")
createEntry (content="~", form="infix", lspace="verythinmathspace", rspace="verythinmathspace")
createEntry (content="@", form="infix", lspace="verythinmathspace", rspace="verythinmathspace")
createEntry (content="--", form="postfix", lspace="verythinmathspace", rspace="0em")
createEntry (content="--", form="prefix", lspace="0em", rspace="verythinmathspace")
createEntry (content="++", form="postfix", lspace="verythinmathspace", rspace="0em")
createEntry (content="++", form="prefix", lspace="0em", rspace="verythinmathspace")
createEntry (content="\u2061", form="infix", lspace="0em", rspace="0em") # ApplyFunction
createEntry (content="?", form="infix", lspace="verythinmathspace", rspace="verythinmathspace")
createEntry (content="_", form="infix", lspace="verythinmathspace", rspace="verythinmathspace")
createEntry (content="\u02D8", form="postfix", accent="true", lspace="0em", rspace="0em") # Breve
createEntry (content="\u00B8", form="postfix", accent="true", lspace="0em", rspace="0em") # Cedilla
createEntry (content="`", form="postfix", accent="true", lspace="0em", rspace="0em") # DiacriticalGrave
createEntry (content="\u02D9", form="postfix", accent="true", lspace="0em", rspace="0em") # DiacriticalDot
createEntry (content="\u02DD", form="postfix", accent="true", lspace="0em", rspace="0em") # DiacriticalDoubleAcute
createEntry (content="\u2190", form="postfix", accent="true", stretchy="true", scaling="horizontal", lspace="0em", rspace="0em") # LeftArrow
createEntry (content="\u2194", form="postfix", accent="true", stretchy="true", scaling="horizontal", lspace="0em", rspace="0em") # LeftRightArrow
createEntry (content="\u294E", form="postfix", accent="true", stretchy="true", scaling="horizontal", lspace="0em", rspace="0em") # LeftRightVector
createEntry (content="\u21BC", form="postfix", accent="true", stretchy="true", scaling="horizontal", lspace="0em", rspace="0em") # LeftVector
createEntry (content="\u00B4", form="postfix", accent="true", lspace="0em", rspace="0em") # DiacriticalAcute
createEntry (content="\u2192", form="postfix", accent="true", stretchy="true", scaling="horizontal", lspace="0em", rspace="0em") # RightArrow
createEntry (content="\u21C0", form="postfix", accent="true", stretchy="true", scaling="horizontal", lspace="0em", rspace="0em") # RightVector
createEntry (content="\u02DC", form="postfix", accent="true", stretchy="true", scaling="horizontal", lspace="0em", rspace="0em") # DiacriticalTilde
createEntry (content="\u00A8", form="postfix", accent="true", lspace="0em", rspace="0em") # DoubleDot
createEntry (content="\u0311", form="postfix", accent="true", lspace="0em", rspace="0em") # DownBreve
createEntry (content="\u02C7", form="postfix", accent="true", stretchy="true", scaling="horizontal", lspace="0em", rspace="0em") # Hacek
createEntry (content="^", form="postfix", accent="true", stretchy="true", scaling="horizontal", lspace="0em", rspace="0em") # Hat
createEntry (content="\u00AF", form="postfix", accent="true", stretchy="true", scaling="horizontal", lspace="0em", rspace="0em") # OverBar
createEntry (content="\uFE37", form="postfix", accent="true", stretchy="true", scaling="horizontal", lspace="0em", rspace="0em") # OverBrace
createEntry (content="\u23B4", form="postfix", accent="true", stretchy="true", scaling="horizontal", lspace="0em", rspace="0em") # OverBracket
createEntry (content="\uFE35", form="postfix", accent="true", stretchy="true", scaling="horizontal", lspace="0em", rspace="0em") # OverParenthesis
createEntry (content="\u20DB", form="postfix", accent="true", lspace="0em", rspace="0em") # TripleDot
createEntry (content="\u0332", form="postfix", accent="true", stretchy="true", scaling="horizontal", lspace="0em", rspace="0em") # UnderBar
createEntry (content="\uFE38", form="postfix", accent="true", stretchy="true", scaling="horizontal", lspace="0em", rspace="0em") # UnderBrace
createEntry (content="\u23B5", form="postfix", accent="true", stretchy="true", scaling="horizontal", lspace="0em", rspace="0em") # UnderBracket
createEntry (content="\uFE36", form="postfix", accent="true", stretchy="true", scaling="horizontal", lspace="0em", rspace="0em") # UnderParenthesis
